@@ -26,33 +26,36 @@ from celery import Celery, signals
 from django.apps import apps
 from django.conf import settings
 
-from df_config.manage import set_env
 
-try:
-    # noinspection PyProtectedMember
-    from celery.app.defaults import _TO_NEW_KEY
-except ImportError:
-    _TO_NEW_KEY = None
-module_name = set_env()
-app = Celery(module_name)
-if _TO_NEW_KEY:
-    # compatibility with the incoming Celery 6 and avoid warning in Celery 5
+def get_project_module_name():
+    module_name = "df_websockets"
+    if hasattr(settings, "DF_MODULE_NAME"):
+        module_name = settings.DF_MODULE_NAME
+    return module_name
 
-    class CelerySetting:
-        pass
 
-    celery_settings = CelerySetting()
-    for old_setting, new_setting in _TO_NEW_KEY.items():
-        if hasattr(settings, old_setting):
-            setattr(celery_settings, new_setting, getattr(settings, old_setting))
-        elif hasattr(settings, new_setting):
-            setattr(celery_settings, new_setting, getattr(settings, new_setting))
-else:
-    celery_settings = settings
+def get_celery_settings():
+    try:
+        # noinspection PyProtectedMember,PyPackageRequirements
+        from celery.app.defaults import _TO_NEW_KEY
+    except ImportError:
+        _TO_NEW_KEY = None
 
-app.config_from_object(celery_settings)
+    if _TO_NEW_KEY:
+        # compatibility with the incoming Celery 6 and avoid warning in Celery 5
 
-app.autodiscover_tasks([a.name for a in apps.app_configs.values()])
+        class CelerySetting:
+            pass
+
+        celery_settings = CelerySetting()
+        for old_setting, new_setting in _TO_NEW_KEY.items():
+            if hasattr(settings, old_setting):
+                setattr(celery_settings, new_setting, getattr(settings, old_setting))
+            elif hasattr(settings, new_setting):
+                setattr(celery_settings, new_setting, getattr(settings, new_setting))
+    else:
+        celery_settings = settings
+    return celery_settings
 
 
 # noinspection PyUnusedLocal
@@ -62,5 +65,9 @@ def setup_celery_logging(**kwargs):
     logging.config.dictConfig(settings.LOGGING)
 
 
+app = Celery(get_project_module_name())
+app.config_from_object(get_celery_settings())
+app.autodiscover_tasks([a.name for a in apps.app_configs.values()])
+
 # Moving the call here works
 app.log.setup()
