@@ -13,7 +13,7 @@
 #  or https://cecill.info/licences/Licence_CeCILL-B_V1-fr.txt (French)         #
 #                                                                              #
 # ##############################################################################
-
+"""Define the web ASGI application."""
 from channels.auth import AuthMiddlewareStack
 from channels.routing import ProtocolTypeRouter, URLRouter
 
@@ -24,17 +24,16 @@ except ImportError:  # django < 3.0
 from django.urls import path
 
 from df_websockets import ws_settings
-from df_websockets.consumers import DFConsumer
+from df_websockets.consumers import DFChannelNameRouter, DFConsumer
 
-consumer = DFConsumer
-if hasattr(DFConsumer, "as_asgi"):
-    consumer = DFConsumer.as_asgi()
 websocket_urlpatterns = [
-    path(ws_settings.WEBSOCKET_URL[1:], consumer),
+    path(ws_settings.WEBSOCKET_URL[1:], DFConsumer.as_asgi()),
 ]
 
 mapping = {
     "websocket": AuthMiddlewareStack(URLRouter(websocket_urlpatterns)),
+    "channel": DFChannelNameRouter(),
+    "celery": DFChannelNameRouter(),
 }
 if ASGIHandler:
     mapping["http"] = ASGIHandler()
