@@ -1,3 +1,18 @@
+# ##############################################################################
+#  This file is part of df_websockets                                          #
+#                                                                              #
+#  Copyright (C) 2020 Matthieu Gallet <github@19pouces.net>                    #
+#  All Rights Reserved                                                         #
+#                                                                              #
+#  You may use, distribute and modify this code under the                      #
+#  terms of the (BSD-like) CeCILL-B license.                                   #
+#                                                                              #
+#  You should have received a copy of the CeCILL-B license with                #
+#  this file. If not, please visit:                                            #
+#  https://cecill.info/licences/Licence_CeCILL-B_V1-en.txt (English)           #
+#  or https://cecill.info/licences/Licence_CeCILL-B_V1-fr.txt (French)         #
+#                                                                              #
+# ##############################################################################
 """WindowInfo object and associated functions
 ==========================================
 
@@ -18,21 +33,6 @@ Designed to be instanciated from a :class:`django.http.request.HttpRequest` and
 (when a signal calls another one). However, a blank :class:`WindowInfo` can also be directly instanciated.
 
 """
-# ##############################################################################
-#  This file is part of df_websockets                                          #
-#                                                                              #
-#  Copyright (C) 2020 Matthieu Gallet <github@19pouces.net>                    #
-#  All Rights Reserved                                                         #
-#                                                                              #
-#  You may use, distribute and modify this code under the                      #
-#  terms of the (BSD-like) CeCILL-B license.                                   #
-#                                                                              #
-#  You should have received a copy of the CeCILL-B license with                #
-#  this file. If not, please visit:                                            #
-#  https://cecill.info/licences/Licence_CeCILL-B_V1-en.txt (English)           #
-#  or https://cecill.info/licences/Licence_CeCILL-B_V1-fr.txt (French)         #
-#                                                                              #
-# ##############################################################################
 
 import logging
 
@@ -53,7 +53,7 @@ class Session:
 
 
 class WindowInfo:
-    """ Built to store the username and the window key and must be supplied to any Python signal call.
+    """Built to store the username and the window key and must be supplied to any Python signal call.
     All attributes are set by "WindowInfoMiddleware"'s.
 
     Can be constructed from a standard :class:`django.http.HttpRequest` or from a dict.
@@ -91,7 +91,7 @@ class WindowInfo:
 
     @classmethod
     def from_request(cls, request):
-        """ return a :class:`df_websockets.window_info.WindowInfo` from a :class:`django.http.HttpRequest`.
+        """return a :class:`df_websockets.window_info.WindowInfo` from a :class:`django.http.HttpRequest`.
 
         If the request already is a :class:`df_websockets.window_info.WindowInfo`,
         then it is returned as-is (not copied!).
@@ -116,8 +116,10 @@ for mdw_ in middlewares:
 
 
 def get_window_context(window_info):
-    """Generate a template context from the `window_info`, equivalent of a template
-    context from a :class:`django.http.request.HttpRequest`."""
+    """Generate a template context from the `window_info`.
+
+    Equivalent of a template context from a :class:`django.http.request.HttpRequest`.
+    """
     context = {}
     if window_info:
         for mdw in middlewares:
@@ -126,8 +128,10 @@ def get_window_context(window_info):
 
 
 def render_to_string(template_name, context=None, window_info=None, using=None):
-    """Render a template to a string using a context from the `window_info`, equivalent of
-the :meth:`django.template.loader.render_to_string`."""
+    """Render a template to a string using a context from the `window_info`.
+
+    Equivalent of the :meth:`django.template.loader.render_to_string`.
+    """
     if window_info is not None and context:
         window_context = get_window_context(window_info)
         window_context.update(context)
