@@ -14,7 +14,7 @@
 #                                                                              #
 # ##############################################################################
 import logging
-from typing import Dict, Any
+from typing import Any, Dict
 
 from django.conf import settings
 from django.contrib.auth import get_user_model
@@ -102,7 +102,7 @@ class DjangoAuthMiddleware(WindowInfoMiddleware):
         window_info._perms = None
         window_info._template_perms = None
         window_info.user_agent = request.META.get("HTTP_USER_AGENT", "")
-        window_info.csrf_cookie = request.COOKIES.get("csrftoken", "")
+        window_info.csrf_cookie = request.COOKIES.get(settings.CSRF_COOKIE_NAME, "")
         if user and user.is_authenticated:
             window_info.user_pk = user.pk
             window_info.username = user.get_username()
@@ -174,8 +174,8 @@ class DjangoAuthMiddleware(WindowInfoMiddleware):
     def get_context(self, window_info):
         """provide the same context data as the :mod:`django.contrib.auth.context_processors`:
 
-         * `user`: a user or :class:`django.contrib.auth.models.AnonymousUser`
-         * `perms`, with the same meaning
+        * `user`: a user or :class:`django.contrib.auth.models.AnonymousUser`
+        * `perms`, with the same meaning
         """
         user = window_info.user or AnonymousUser()
         return {
@@ -198,7 +198,7 @@ class DjangoAuthMiddleware(WindowInfoMiddleware):
             return None
 
         def has_perm(req, perm):
-            """ return true is the user has the required perm.
+            """return true is the user has the required perm.
 
             >>> from df_websockets.window_info import WindowInfo
             >>> r = WindowInfo.from_dict({'username': 'username', 'perms':['app_label.codename']})
